@@ -1,28 +1,27 @@
-use strict; #-*-cperl-*-
+use strict;
 use warnings;
 
-use lib qw( ../../.. );
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Easy - evolutionary algorithm, single generation, with 
+    Algorithm::Evolutionary::Op::Easy - evolutionary algorithm, single generation, with 
                     variable operators.
                  
 
 =head1 SYNOPSIS
 
-  my $easy_EA = new Algorithm::Evolutionary::Op::Easy $fitness_func;
+  my $easyEA = Algorithm::Evolutionary::Op::Base->fromXML( $ref->{initial}{section}{pop}{op} );
+  # Parsed XML fragment, see samples
 
-  for ( my $i = 0; $i < $max_generations; $i++ ) {
+  for ( my $i = 0; $i < $ref->{initial}{section}{pop}{op}{param}{maxgen}{value}; $i++ ) {
     print "<", "="x 20, "Generation $i", "="x 20, ">\n"; 
-    $easy_EA->apply(\@pop ); 
+    $easyEA->apply(\@pop ); 
     for ( @pop ) { 
       print $_->asString, "\n"; 
     } 
   }
 
   #Define a default algorithm with predefined evaluation function,
-  #Mutation and crossover. Default selection rate is 0.4
+  #Mutation and crossover. Default selection rate ls 4
   my $algo = new Algorithm::Evolutionary::Op::Easy( $eval ); 
 
   #Define an easy single-generation algorithm with predefined mutation and crossover
@@ -32,7 +31,7 @@ Algorithm::Evolutionary::Op::Easy - evolutionary algorithm, single generation, w
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base>
+L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =cut
 
@@ -49,26 +48,24 @@ iteration of the algorithm to the population it takes as input
 
 package Algorithm::Evolutionary::Op::Easy;
 
-our ($VERSION) = ( '$Revision: 3.5 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.4 $ ' =~ /(\d+\.\d+)/ ) ;
 
 use Carp;
-
 use Algorithm::Evolutionary::Wheel;
 use Algorithm::Evolutionary::Op::Bitflip;
 use Algorithm::Evolutionary::Op::Crossover;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 # Class-wide constants
 our $APPLIESTO =  'ARRAY';
+our $ARITY = 1;
 
-=head2 new( $eval_func, [$operators_arrayref] )
+=head2 new
 
-Creates an algorithm that optimizes the handled fitness function and
-reference to an array of operators. If this reference is null, an
-array consisting of bitflip mutation and 2 point crossover is
-generated. Which, of course, might not what you need in case you
-don't have a binary chromosome.
+Creates an algorithm, with the usual operators. Includes a default mutation
+and crossover, in case they are not passed as parameters
 
 =cut
 
@@ -91,9 +88,10 @@ sub new {
 
 }
 
-=head2 set( $hashref, codehash, opshash )
+=head2 set
 
-Sets the instance variables. Takes a ref-to-hash (for options), codehash (for fitness) and opshash (for operators)
+Sets the instance variables. Takes a ref-to-hash as
+input
 
 =cut
 
@@ -105,7 +103,7 @@ sub set {
   $self->{_selrate} = $hashref->{selrate};
 
   for ( keys %$codehash ) {
-    $self->{"_$_"} =  eval "sub {  $codehash->{$_} } " || carp "Error compiling fitness function: $! => $@";
+	$self->{"_$_"} =  eval "sub {  $codehash->{$_} } " || carp "Error compiling fitness function: $! => $@";
   }
 
   $self->{_ops} =();
@@ -116,7 +114,7 @@ sub set {
   }
 }
 
-=head2 apply( $population )
+=head2 apply
 
 Applies the algorithm to the population; checks that it receives a
 ref-to-array as input, croaks if it does not. Returns a sorted,
@@ -127,6 +125,7 @@ culled, evaluated population for next generation.
 sub apply ($) {
   my $self = shift;
   my $pop = shift || croak "No population here";
+  croak "Incorrect type ".(ref $pop) if  ref( $pop ) ne $APPLIESTO;
 
   #Evaluate
   my $eval = $self->{_eval};
@@ -135,21 +134,31 @@ sub apply ($) {
   for ( @$pop ) {
     my $fitness;  #Evaluates only those that have no fitness
     if ( !defined ($_->Fitness() ) ) {
-      $_->evaluate( $eval );
+      $fitness = $eval->( $_ );
+      $_->Fitness( $fitness );
     }
     push @popEval, $_;
   }
 
-  #Sort by fitness
+  #Sort
   my @popsort = sort { $b->{_fitness} <=> $a->{_fitness}; }
-    @popEval ;
+					  @popEval ;
 
   #Cull
   my $pringaos = int(($#popsort+1)*$self->{_selrate}); #+1 gives you size
-  splice @popsort, -$pringaos;
+  splice @popsort, $#popsort - $pringaos, $pringaos;
  
   #Reproduce
-  my @rates = map( $_->{'rate'}, @ops );
+  my $totRate = 0;
+  my @rates;
+  for ( @ops ) {
+      if ( $_->{'rate'} ) {
+	  push( @rates, $_->{'rate'});
+      } else {
+	  croak 'Operator has no rate!n\n';
+      }
+
+  }
   my $opWheel = new Algorithm::Evolutionary::Wheel @rates;
 
   #Generate offpring;
@@ -157,37 +166,45 @@ sub apply ($) {
   for ( my $i = 0; $i < $pringaos; $i ++ ) {
       my @offspring;
       my $selectedOp = $ops[ $opWheel->spin()];
-      croak "Problems with selected operator" if !$selectedOp;
       for ( my $j = 0; $j < $selectedOp->arity(); $j ++ ) {
-	my $chosen = $popsort[ int ( rand( $originalSize ) )];
-	push( @offspring, $chosen ); #No need to clone, it's not changed in ops
+	  my $chosen = $popsort[ rand( $originalSize )];
+	  push( @offspring, $chosen->clone() );
       }
-#     p rint "Op ", ref $selectedOp, "\n";
-#      if ( (ref $selectedOp ) =~ /ssover/ ) {
-#	print map( $_->{'_str'}."\n", @offspring );
-#      }
       my $mutante = $selectedOp->apply( @offspring );
-      croak "Error aplying operator" if !$mutante;
- #     print "Mutante ", $mutante->{'_str'}, "\n";
       push( @popsort, $mutante );
   }
+#  for ( @ops ) {
+#	my $relRate = $_->{rate} / $totRate;
+#	for ( my $i = 0; $i < $pringaos*$relRate; $i++ ) {
+#	  my @offspring;
+#	  for ( my $j = 0; $j < $_->arity(); $j ++ ) {
+#		my $chosen = $popsort[ rand( $#popsort )];
+#		push( @offspring, $chosen->clone() );
+#	  }
+#	  my $mutante = $_->apply( @offspring );
+#	  push( @popsort, $mutante );
+#	}
+#  }
 
   #Return
-  @$pop = @popsort;
+  for ( my $i = 0; $i <= $#popsort; $i++ ) {
+#	print $i, "->", $popsort[$i]->asString, "\n";
+      $pop->[$i] = $popsort[$i];
+  }
+
   
 }
 
-=head1 SEE ALSO
-
-L<Algorithm::Evolutionary::Op::CanonicalGA>.
-L<Algorithm::Evolutionary::Op::FullAlgorithm>.
-
-
 =head1 Copyright
   
-This file is released under the GPL. See the LICENSE file included in this distribution,
-or go to http://www.fsf.org/licenses/gpl.txt
+  This file is released under the GPL. See the LICENSE file included in this distribution,
+  or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/04/30 16:42:40 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Easy.pm,v 1.4 2008/04/30 16:42:40 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.4 $
+  $Name $
 
 =cut
 
